package blog;

import java.util.Map;

/**
 * Interface representing a document to be indexed.  Documents consist of two parts, the content blob and metadata.
 * Metadata is a set of key/value pairs.  The content is a text blob.
 *
 * The id is the id external to indexing.  The docId string is how sets of items are communicated back
 * the system using an index.  The document id is indexed using "DOC_ID" as a key along with the metadata.
 */
public interface DocumentData {
    /**
     * The content blob to be indexed
     * @return the string value of the content.
     */
    public String getContent();

    /**
     * The set of key value pairs to be indexed as metadata.
     * @return a map of key value pairs.
     */
    public Map<String, String> getMetadata();

    /**
     * The system's idea of an id as a string.
     * @return the document id as it is indexed.
     */
    public String getDocId();
}
