package blog;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.Reader;

/**
 * Tragically silly csv reader.  This only splits by ',' and meant solely to support example.csv.
 */
public class ExampleCsvReader {

    private BufferedReader r;
    private int lineCount;

    public ExampleCsvReader(BufferedReader r) {
        this.r = r;
        lineCount = 0;
    }

    /**
     * The first line is the definitions of the keys for the metadata
     * @return a string array of csv cells.
     * @throws IOException Exceptions for any underlying IO problems.
     */
    public String[] readHeader() throws IOException {
        String ln = r.readLine();
        if( ln == null || ln.length() == 0 )
            return null;
        lineCount = 0;
        return convertLine(ln);
    }

    /**
     * Read the current line of cells.
     * @return a string array of csv cells.
     * @throws IOException Exceptions for any underlying IO problems.
     */
    public String[] readCells() throws IOException {
        String ln = r.readLine();
        if( ln == null || ln.length() == 0 )
            return null;
        lineCount++;
        return convertLine(ln);
    }

    protected String[] convertLine(String ln) {
        ln = ln.replaceAll("^\"", "");
        ln = ln.replaceAll("\"$", "");

        return ln.split("\",\"");
    }

    /**
     * Return the last line number read in, starting from 0.  It is assumed there is a header line and that
     * line number is 0.
     * @return the last read in line number.
     */
    public int getLineCount() {
        return lineCount;
    }
}
